#
# spec file for package python-blockdiag
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-blockdiag
Version:        3.0.0
Release:        3.3
Summary:        Program to generate block-diagram images from text
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            http://blockdiag.com/
Source:         https://files.pythonhosted.org/packages/source/b/blockdiag/blockdiag-%{version}.tar.gz
# PATCH-FIX-UPSTREAM python-blockdiag-nose-to-pytest.patch gh#blockdiag/blockdiag#131 pgajdos@suse.com
# Remove the last silly dependency on nose
Patch0:         python-blockdiag-nose-to-pytest.patch
# PATCH-FIX-UPSTREAM https://github.com/blockdiag/blockdiag/pull/179 Add support for Pillow 10
Patch1:         pillow10.patch
BuildRequires:  %{python_module Pillow >= 3}
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module funcparserlib >= 1.0.0~a0}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module webcolors}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Pillow >= 3
Requires:       python-funcparserlib >= 1.0.0~a0
Requires:       python-setuptools
Requires:       python-webcolors
Requires(post): update-alternatives
Requires(preun):update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module reportlab}
BuildRequires:  %{python_module docutils}
BuildRequires:  %{python_module pytest}
# /SECTION
%if 0%{?suse_version} || 0%{?fedora_version} >= 24
Recommends:     ghostscript
Recommends:     python-Wand
Recommends:     python-reportlab
%endif
%python_subpackages

%description
The blockdiag package generates block-diagram image files
from spec-text files.

%prep
%autosetup -p1 -n blockdiag-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%python_clone -a %{buildroot}%{_bindir}/blockdiag

%post
%python_install_alternative blockdiag

%postun
%python_uninstall_alternative blockdiag

%check
pushd src
# other disabled tests:
# [    9s] WARNING: Could not retrieve: http://blockdiag.com/favicon.ico
# [    9s] WARNING: Could not retrieve: http://upload.wikimedia.org/wikipedia/commons/9/9b/Scalable_Vector_Graphics_Circle2.svg
# [    9s] WARNING: Could not retrieve: http://people.sc.fsu.edu/~jburkardt/data/eps/circle.eps
%pytest -k 'not (test_app_cleans_up_images or test_node_attribute or test_setup_inline_svg_is_true_with_multibytes)'
popd

%files %{python_files}
%license LICENSE
%doc CHANGES.rst README.rst
%python_alternative %{_bindir}/blockdiag
%{python_sitelib}/blockdiag
%{python_sitelib}/blockdiag-%{version}*-info

%changelog
* Tue Oct  3 2023 Markéta Machová <mmachova@suse.com>
- Add upstream pillow10.patch to fix compatibility with Pillow 10.0.0
* Wed May  3 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Aug  4 2022 Ben Greiner <code@bnavigator.de>
- Update to 3.0.0
  * Drop python3.6 support
  * Use funcparserlib-1.0.0a0 or newer to support new python
    versions
  * Allow to write multiline string via triple quotes (""" ... """)
  * Fix #147: file existence disclosure using svg renderer
- Refresh python-blockdiag-nose-to-pytest.patch
* Wed Sep  1 2021 pgajdos@suse.com
- added patches
  https://github.com/blockdiag/blockdiag/pull/131
  + python-blockdiag-nose-to-pytest.patch
* Mon Aug 30 2021 pgajdos@suse.com
- %%check: test the package
* Mon Feb 24 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 2.0.1:
  * Drop python2 and python3.4 support
  * Fix #126: '_io.BufferedRandom' object has no attribute 'buffer'
  * Fix #109 blockdiag does not work with recent pillow
* Thu Feb 28 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.5.4:
  * better python 3.7 compatibility
* Wed Dec  5 2018 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Tue Mar  6 2018 aplanas@suse.com
- Allows Recommends and Suggest in Fedora
* Tue Feb 27 2018 aplanas@suse.com
- Recommends only for SUSE
* Thu Apr 20 2017 toddrme2178@gmail.com
- Implement single-spec version.
* Thu Dec  1 2016 termim@gmail.com
- use update-alternatives
* Thu May 12 2016 tbechtold@suse.com
- update to 1.5.3:
  * Fix #67 Group overlaps with nodes having href
* Fri Jul 10 2015 tbechtold@suse.com
- Initial packaging
